@@ -46,6 +46,28 @@ export function addNodeActionCommands(
         return node ?? null;
     }
 
+    function gatherNodeInPortValues(node) {
+        const nodePorts = node.getInPorts();
+        const model_params_dict = {};
+        Object.values(nodePorts).map(port => {
+            // @ts-ignore
+            const targetPortLinks = port.getLinks();
+            if (targetPortLinks) {
+                Object.values(targetPortLinks).map(link => {
+                    // @ts-ignore
+                    const sourceNode = link.getSourcePort().getParent();
+                    if (sourceNode.name.includes('Literal')) {
+                        const model_param = sourceNode.getOutPorts()[0].getOptions();
+                        // @ts-ignore
+                        const label = port.getOptions().label[0] === "★" ? port.getOptions().label.slice(1) : port.getOptions().label;
+                        model_params_dict[label] = model_param.label;
+                    }
+                });
+            }
+        });
+        return model_params_dict;
+    }
+
     //Add command to open node's viewer in notebook
     commands.addCommand(commandIDs.openViewer, {
         execute: async (args) => {
@@ -58,8 +80,13 @@ export function addNodeActionCommands(
                 return;
             }
 
-            const dataToSend = { 'component': node.name, 'path':  node.extras.path,
-                'component_id': node.options.id, 'xircuits_id': node.parent.parent.options.id };
+            const dataToSend = {
+                'component': node.name,
+                'component_id': node.options.id,
+                'component_inputs': gatherNodeInPortValues(node),
+                'path':  node.extras.path,
+                'xircuits_id': node.parent.parent.options.id
+            };
 
             const response = await requestAPI<any>('components/', {
 				body: JSON.stringify(dataToSend),
@@ -70,9 +97,10 @@ export function addNodeActionCommands(
             await app.commands.execute(
                 commandIDs.openDocManager,
                 {
-                    path: response["widget"],
+                    path: response['widget'],
                     factory: 'Notebook',
-                    kernel: { name: 'python3' }
+                    kernel: { name: 'python3' },
+                    options: { mode: 'split-right' }
                 });
         }
     });
@@ -566,11 +594,13 @@ export function addNodeActionCommands(
             let node = null;
             const links = widget.xircuitsApp.getDiagramEngine().getModel()["layers"][0]["models"];
             const oldValue = selected_node.getPorts()["out-0"].getOptions()["label"];
-            const literalType = selected_node["name"].split(" ")[1];
+            let literalType = selected_node["name"];
+            literalType = literalType.substring(literalType.indexOf(' ') + 1);  // return everything after the first space
             let isStoreDataType: boolean = false;
             let isTextareaInput: string = "";
 
             switch(literalType){
+                case "Numpy Array":
                 case "String":
                     isTextareaInput = 'textarea';
                     break;
