@@ -84,6 +84,7 @@ export const Layer = styled.div`
 
 export const commandIDs = {
 	openXircuitEditor: 'Xircuit-editor:open',
+	openTvbExtUnicore: 'tvbextunicore:open',
 	openDocManager: 'docmanager:open',
 	newDocManager: 'docmanager:new-untitled',
 	saveDocManager: 'docmanager:save',
@@ -374,6 +375,8 @@ export const BodyWidget: FC<BodyWidgetProps> = ({
 		let pythonCode = 'from argparse import ArgumentParser\n';
 		pythonCode += 'from datetime import datetime\n';
 		pythonCode += 'from time import sleep\n';
+		pythonCode += 'import numpy\n';
+		pythonCode += 'import numpy as np\n';
 		if (debuggerMode == true) {
 			pythonCode += 'import json, os, signal\n';
 			pythonCode += 'from flask import Flask, jsonify, request\n';
@@ -394,7 +397,8 @@ export const BodyWidget: FC<BodyWidgetProps> = ({
 				nodeType === 'boolean' ||
 				nodeType === 'int' ||
 				nodeType === 'float' ||
-				nodeType === 'string') { }
+				nodeType === 'string' ||
+				nodeType === 'numpy.ndarray') { }
 			else {
 				uniqueComponents[componentName] = componentName;
 			}
@@ -458,7 +462,8 @@ export const BodyWidget: FC<BodyWidgetProps> = ({
 				nodeType === 'boolean' ||
 				nodeType === 'int' ||
 				nodeType === 'float' ||
-				nodeType === 'string') {
+				nodeType === 'string' ||
+				nodeType === 'numpy.ndarray') {
 			} else {
 				let bindingName = 'c_' + i;
 				let componentName = allNodes[i]["name"];
@@ -551,6 +556,9 @@ export const BodyWidget: FC<BodyWidgetProps> = ({
 												case "dict":
 													sourcePortLabelStructure = "{" + sourcePortLabel + "}";
 													break;
+												case "numpy.ndarray":
+													sourcePortLabelStructure = sourcePortLabel;
+													break;
 												default:
 													sourcePortLabelStructure = sourcePortLabel;
 													break;
@@ -690,6 +698,8 @@ export const BodyWidget: FC<BodyWidgetProps> = ({
 
 			pythonCode += "if __name__ == '__main__':\n";
 			pythonCode += '    ' + 'parser = ArgumentParser()\n';
+			pythonCode += '    ' + "parser.add_argument('--is_hpc_launch', default=False, type=bool)\n";
+
 
 			if (stringNodes) {
 				for (let i = 0; i < stringNodes.length; i++) {
@@ -1460,11 +1470,14 @@ export const BodyWidget: FC<BodyWidgetProps> = ({
 		let runType = dialogResult["value"]['runType'] ?? "";
 		let runConfig = dialogResult["value"]['runConfig'] ?? "";
 		let runProject = dialogResult["value"]['project'] ?? "";
+		let runStageOut = dialogResult["value"]['stage-out'] ?? "";
+		let runMonitoring = dialogResult["value"]['monitoring'] ?? "";
 		if (runConfigs.length != 0) {
 			runConfigs.map(cfg => {
 				if (cfg.run_type == runType && cfg.run_config_name == runConfig) {
 					config = cfg;
 					cfg['project'] = runProject;
+					cfg['stage-out'] = runStageOut;
 					setLastConfigs(cfg);
 				}
 			})
@@ -1521,6 +1534,10 @@ export const BodyWidget: FC<BodyWidgetProps> = ({
 				}
 			});
 		}
+		if (runType !== '' && runMonitoring) {
+			// It means a remote launch was started
+			await app.commands.execute(commandIDs.openTvbExtUnicore);
+		}
 		return { commandStr, config };
 	};
 
